/*
 * The MIT License (MIT)
 *
 * Copyright © 2023 xrv <xrv@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.util;

import com.tzld.crawler.etl.model.dto.VideoInfoDto;
import net.bramp.ffmpeg.FFmpeg;
import net.bramp.ffmpeg.FFprobe;
import net.bramp.ffmpeg.probe.FFmpegFormat;
import net.bramp.ffmpeg.probe.FFmpegProbeResult;
import net.bramp.ffmpeg.probe.FFmpegStream;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

/**
 * @author ehlxr
 * @since 2023-06-26 18:01.
 */
public class VideoUtils {
    private final static Logger log = LoggerFactory.getLogger(VideoUtils.class);

    public static VideoInfoDto getVideoInfo(String videoPath, String ffprobePath) {
        try {
            FFprobe ffprobe = new FFprobe(ffprobePath);
            FFmpegProbeResult probeResult = ffprobe.probe(videoPath);

            FFmpegFormat format = probeResult.getFormat();

            FFmpegStream stream = probeResult.getStreams().get(0);
            return VideoInfoDto.newBuilder()
                    .duration((long) format.duration)
                    .height(stream.height)
                    .width(stream.width)
                    .build();
        } catch (Exception e) {
            log.error("get video {} info by ffprobe error.", videoPath, e);
            return null;
        }
    }

    public static void videoCompose(String videoPath, String audioPath, String outPath) {
        try {
            FFmpeg ffmpeg = new FFmpeg("ffmpeg");
            // ffmpeg.
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
